==> openshift-model-machine-6.7.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/UnhealthyConditionBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UnhealthyConditionBuilder extends UnhealthyConditionFluentImpl<UnhealthyConditionBuilder> implements VisitableBuilder<UnhealthyCondition,UnhealthyConditionBuilder>{
  public UnhealthyConditionBuilder() {
    this(false);
  }
  public UnhealthyConditionBuilder(Boolean validationEnabled) {
    this(new UnhealthyCondition(), validationEnabled);
  }
  public UnhealthyConditionBuilder(UnhealthyConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public UnhealthyConditionBuilder(UnhealthyConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UnhealthyCondition(), validationEnabled);
  }
  public UnhealthyConditionBuilder(UnhealthyConditionFluent<?> fluent,UnhealthyCondition instance) {
    this(fluent, instance, false);
  }
  public UnhealthyConditionBuilder(UnhealthyConditionFluent<?> fluent,UnhealthyCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withStatus(instance.getStatus());
      fluent.withTimeout(instance.getTimeout());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UnhealthyConditionBuilder(UnhealthyCondition instance) {
    this(instance,false);
  }
  public UnhealthyConditionBuilder(UnhealthyCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withStatus(instance.getStatus());
      this.withTimeout(instance.getTimeout());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UnhealthyConditionFluent<?> fluent;
  Boolean validationEnabled;
  public UnhealthyCondition build() {
    UnhealthyCondition buildable = new UnhealthyCondition(fluent.getStatus(),fluent.getTimeout(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-machine-6.8.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/UnhealthyConditionBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UnhealthyConditionBuilder extends UnhealthyConditionFluent<UnhealthyConditionBuilder> implements VisitableBuilder<UnhealthyCondition,UnhealthyConditionBuilder>{
  public UnhealthyConditionBuilder() {
    this(false);
  }
  public UnhealthyConditionBuilder(Boolean validationEnabled) {
    this(new UnhealthyCondition(), validationEnabled);
  }
  public UnhealthyConditionBuilder(UnhealthyConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public UnhealthyConditionBuilder(UnhealthyConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UnhealthyCondition(), validationEnabled);
  }
  public UnhealthyConditionBuilder(UnhealthyConditionFluent<?> fluent,UnhealthyCondition instance) {
    this(fluent, instance, false);
  }
  public UnhealthyConditionBuilder(UnhealthyConditionFluent<?> fluent,UnhealthyCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new UnhealthyCondition());

    if (instance != null) {
      fluent.withStatus(instance.getStatus());
      fluent.withTimeout(instance.getTimeout());
      fluent.withType(instance.getType());
      fluent.withStatus(instance.getStatus());
      fluent.withTimeout(instance.getTimeout());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public UnhealthyConditionBuilder(UnhealthyCondition instance) {
    this(instance,false);
  }
  public UnhealthyConditionBuilder(UnhealthyCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new UnhealthyCondition());

    if (instance != null) {
      this.withStatus(instance.getStatus());
      this.withTimeout(instance.getTimeout());
      this.withType(instance.getType());
      this.withStatus(instance.getStatus());
      this.withTimeout(instance.getTimeout());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  UnhealthyConditionFluent<?> fluent;
  Boolean validationEnabled;
  public UnhealthyCondition build() {
    UnhealthyCondition buildable = new UnhealthyCondition(fluent.getStatus(),fluent.getTimeout(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
